.. rst-class:: detail

GetJoints
====================

.. currentmodule:: compas_rrc

.. autoclass:: GetJoints

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~GetJoints.__init__
        ~GetJoints.from_msg
        ~GetJoints.parse_feedback
    
    